@@ -292,24 +292,26 @@ module FFI
     end
 
     # @overload attach_variable(mname, cname, type)
-    #  @example
-    #   module Bar
-    #     extend FFI::Library
-    #     ffi_lib 'my_lib'
-    #     attach_variable :c_myvar, :myvar, :long
-    #   end
-    #   # now callable via Bar.c_myvar
+    #   @param [#to_s] mname name of ruby method to attach as
+    #   @param [#to_s] cname name of C variable to attach
+    #   @param [DataConverter, Struct, Symbol, Type] type C variable's type
+    #   @example
+    #     module Bar
+    #       extend FFI::Library
+    #       ffi_lib 'my_lib'
+    #       attach_variable :c_myvar, :myvar, :long
+    #     end
+    #     # now callable via Bar.c_myvar
     # @overload attach_variable(cname, type)
-    #  @example
-    #   module Bar
-    #     extend FFI::Library
-    #     ffi_lib 'my_lib'
-    #     attach_variable :myvar, :long
-    #   end
-    #   # now callable via Bar.myvar
-    # @param [#to_s] mname name of ruby method to attach as
-    # @param [#to_s] cname name of C variable to attach
-    # @param [DataConverter, Struct, Symbol, Type] type C varaible's type
+    #   @param [#to_s] mname name of ruby method to attach as
+    #   @param [DataConverter, Struct, Symbol, Type] type C variable's type
+    #   @example
+    #     module Bar
+    #       extend FFI::Library
+    #       ffi_lib 'my_lib'
+    #       attach_variable :myvar, :long
+    #     end
+    #     # now callable via Bar.myvar
     # @return [DynamicLibrary::Symbol]
     # @raise {FFI::NotFoundError} if +cname+ cannot be found in libraries
     #
@@ -360,10 +362,12 @@ module FFI
 
 
     # @overload callback(name, params, ret)
+    #   @param name callback name to add to type map
+    #   @param [Array] params array of parameters' types
+    #   @param [DataConverter, Struct, Symbol, Type] ret callback return type
     # @overload callback(params, ret)
-    # @param name callback name to add to type map
-    # @param [Array] params array of parameters' types
-    # @param [DataConverter, Struct, Symbol, Type] ret callback return type
+    #   @param [Array] params array of parameters' types
+    #   @param [DataConverter, Struct, Symbol, Type] ret callback return type
     # @return [FFI::CallbackInfo]
     def callback(*args)
       raise ArgumentError, "wrong number of arguments" if args.length < 2 || args.length > 3
@@ -388,10 +392,6 @@ module FFI
       cb
     end
 
-    # @param [DataConverter, Symbol, Type] old
-    # @param  add
-    # @param [] info
-    # @return [FFI::Enum, FFI::Type]
     # Register or get an already registered type definition.
     #
     # To register a new type definition, +old+ should be a {FFI::Type}. +add+
@@ -404,6 +404,11 @@ module FFI
     # * in others cases, +info+ is used to create a named enum.
     #
     # If +old+ is a key for type map, #typedef get +old+ type definition.
+    #
+    # @param [DataConverter, Symbol, Type] old
+    # @param [Symbol] add
+    # @param [Symbol] info
+    # @return [FFI::Enum, FFI::Type]
     def typedef(old, add, info=nil)
       @ffi_typedefs = Hash.new unless defined?(@ffi_typedefs)
 
@@ -444,9 +449,29 @@ module FFI
     #  @example
     #   enum [:zero, :one, :two]  # unnamed enum, equivalent to above example
     #  @param [Array] values values for enum
+    # @overload enum(native_type, name, values)
+    #  Create a named enum and specify the native type.
+    #  @example
+    #   enum FFI::Type::UINT64, :foo, [:zero, :one, :two]  # named enum
+    #  @param [FFI::Type] native_type native type for new enum
+    #  @param [Symbol] name name for new enum
+    #  @param [Array] values values for enum
+    # @overload enum(native_type, *args)
+    #  Create an unnamed enum and specify the native type.
+    #  @example
+    #   enum FFI::Type::UINT64, :zero, :one, :two  # unnamed enum
+    #  @param [FFI::Type] native_type native type for new enum
+    #  @param args values for enum
+    # @overload enum(native_type, values)
+    #  Create an unnamed enum and specify the native type.
+    #  @example
+    #   enum Type::UINT64, [:zero, :one, :two]  # unnamed enum, equivalent to above example
+    #  @param [FFI::Type] native_type native type for new enum
+    #  @param [Array] values values for enum
     # @return [FFI::Enum]
     # Create a new {FFI::Enum}.
     def enum(*args)
+      native_type = args.first.kind_of?(FFI::Type) ? args.shift : nil
       name, values = if args[0].kind_of?(Symbol) && args[1].kind_of?(Array)
         [ args[0], args[1] ]
       elsif args[0].kind_of?(Array)
@@ -455,7 +480,7 @@ module FFI
         [ nil, args ]
       end
       @ffi_enums = FFI::Enums.new unless defined?(@ffi_enums)
-      @ffi_enums << (e = FFI::Enum.new(values, name))
+      @ffi_enums << (e = native_type ? FFI::Enum.new(native_type, values, name) : FFI::Enum.new(values, name))
 
       # If called as enum :foo, [ :zero, :one, :two ], add a typedef alias
       typedef(e, name) if name
