@@ -1,3 +1,8 @@
+#
+# This file is part of ruby-ffi.
+# For licensing, see LICENSE.SPECS
+#
+
 require File.expand_path(File.join(File.dirname(__FILE__), "spec_helper"))
 
 class Timeval < FFI::Struct
@@ -8,6 +13,6 @@ describe FFI::Struct do
   it "allows setting fields" do
     t = Timeval.new
     t[:tv_sec] = 12
-    t[:tv_sec].should == 12
+    expect(t[:tv_sec]).to eq(12)
   end
-end
\ No newline at end of file
+end
